@@ -1,4 +1,5 @@
 from pkgutil import extend_path
+
 __path__ = extend_path(__path__, __name__)
 
 
@@ -17,7 +18,7 @@ from .__version__ import (
     __author__,
     __author_email__,
     __licence__,
-    __cookie_cutter_version__
+    __cookie_cutter_version__,
 )
 
-_file_source = 'masonite'
+_file_source = "masonite"
