@@ -1,6 +1,10 @@
 """CSRF Protection Module."""
 import binascii
 import os
+from hmac import compare_digest
+from .Sign import Sign
+from ..exceptions import InvalidCSRFToken
+from cryptography.fernet import InvalidToken
 
 
 class Csrf:
@@ -24,8 +28,8 @@ class Csrf:
         Returns:
             string -- Returns token generated.
         """
-        token = bytes(binascii.b2a_hex(os.urandom(length // 2))).decode("utf-8")
-        self.request.cookie("csrf_token", token, encrypt=False)
+        token = self.request.get_cookie("MSESSID")
+        self.request.cookie("csrf_token", token)
         return token
 
     def verify_csrf_token(self, token):
@@ -37,7 +41,14 @@ class Csrf:
         Returns:
             bool
         """
-        if self.request.get_cookie("csrf_token", decrypt=False) == token:
+        try:
+            token = Sign().unsign(token)
+        except (InvalidToken, TypeError):
+            pass
+
+        if self.request.get_cookie("csrf_token") and compare_digest(
+            self.request.get_cookie("csrf_token"), token
+        ):
             return True
         else:
             return False
