@@ -65,7 +65,12 @@ class NewCommand(Command):
             self.set_api_provider_url_for_repo(provider, repo)
 
             # find cookie-cutter version to use when doing 'craft new' only
-            if repo == "MasoniteFramework/cookie-cutter" and provider == "github" and branch == "False" and version == "False":
+            if (
+                repo == "MasoniteFramework/cookie-cutter"
+                and provider == "github"
+                and branch == "False"
+                and version == "False"
+            ):
                 branch = __cookie_cutter_version__
 
             if branch != "False":
