@@ -8,13 +8,7 @@ from .InstallCommand import InstallCommand
 from .JobCommand import JobCommand
 from .KeyCommand import KeyCommand
 from .MailableCommand import MailableCommand
-from .MakeMigrationCommand import MakeMigrationCommand
 from .MiddlewareCommand import MiddlewareCommand
-from .MigrateCommand import MigrateCommand
-from .MigrateRefreshCommand import MigrateRefreshCommand
-from .MigrateResetCommand import MigrateResetCommand
-from .MigrateRollbackCommand import MigrateRollbackCommand
-from .MigrateStatusCommand import MigrateStatusCommand
 from .ModelCommand import ModelCommand
 from .ModelDocstringCommand import ModelDocstringCommand
 from .NewCommand import NewCommand
