@@ -1,4 +1,4 @@
-const mix = require('laravel-mix');
+const mix = require("laravel-mix");
 
 /*
  |--------------------------------------------------------------------------
@@ -11,5 +11,7 @@ const mix = require('laravel-mix');
  |
  */
 
-mix.js('resources/js/app.js', 'public/js')
-    .sass('resources/sass/app.scss', 'public/css');
\ No newline at end of file
+mix
+  .js("resources/js/app.js", "public/js")
+  .vue({ version: 2 })
+  .sass("resources/sass/app.scss", "public/css");
