@@ -92,3 +92,15 @@ class AmbiguousError(Exception):
 
 class ProjectLimitReached(Exception):
     pass
+
+
+class ProjectProviderTimeout(Exception):
+    pass
+
+
+class ProjectProviderHttpError(Exception):
+    pass
+
+
+class ProjectTargetNotEmpty(Exception):
+    pass
