@@ -1,9 +1,16 @@
 from .static import static
 from .password import password
-from .misc import random_string, dot, clean_request_input, HasColoredCommands, Compact as compact, deprecated
+from .misc import (
+    random_string,
+    dot,
+    clean_request_input,
+    HasColoredCommands,
+    Compact as compact,
+    deprecated,
+)
 from .Extendable import Extendable
 from .time import cookie_expire_time, parse_human_time
 from .optional import Optional as optional
 from .structures import config, Dot, load
 from .migrations import has_unmigrated_migrations
-from orator.support.collection import Collection as collect
+from masoniteorm.collection import Collection as collect
