@@ -12,7 +12,9 @@ def set_request_method(method_type):
     Returns:
         string -- An input string.
     """
-    return Markup("<input type='hidden' name='__method' value='{0}'>".format(method_type))
+    return Markup(
+        "<input type='hidden' name='__method' value='{0}'>".format(method_type)
+    )
 
 
 def back(location=None):
@@ -26,17 +28,23 @@ def back(location=None):
     """
     if location is None:
         from wsgi import container
-        location = container.make('Request').path
+
+        request = container.make("Request")
+        intended_route = request.session.get("__intend")
+        if intended_route:
+            location = intended_route
+        else:
+            location = request.path
 
     return Markup("<input type='hidden' name='__back' value='{0}'>".format(location))
 
 
-def hidden(value, name='hidden-input'):
+def hidden(value, name="hidden-input"):
     return Markup("<input type='hidden' name='{}' value='{}'>".format(name, value))
 
 
-def old(session_key, default=''):
-    """Return the old value submitted by forms validated with Valitators.
+def old(session_key, default=""):
+    """Return the old value submitted by forms validated with validators.
 
     Arguments:
         session_key {string} -- The key flashed to session.
@@ -46,8 +54,9 @@ def old(session_key, default=''):
     """
 
     from wsgi import container
-    session_container = container.make('Session')
+
+    session_container = container.make("Session")
 
     if session_container.has(session_key):
-        return session_container.get(session_key)
+        return session_container.get_flashed(session_key)
     return default
