@@ -15,8 +15,8 @@ class CorsProvider(ServiceProvider):
 
     def boot(self, request: Request, response: Response):
         """Boots services required by the container."""
-        headers = config('middleware.cors') or {}
+        headers = config("middleware.cors") or {}
         request.header(headers)
 
-        if request.get_request_method().lower() == 'options':
-            response.view('preflight')
+        if request.get_request_method().lower() == "options":
+            response.view("preflight")
