@@ -153,6 +153,17 @@ class Request(Extendable):
 
         return False
 
+    def is_not_safe(self):
+        """Check if the current request is not a get request.
+
+        Returns:
+            bool
+        """
+        if not self.environ["REQUEST_METHOD"] == "GET" and not self.environ["REQUEST_METHOD"] == "OPTIONS" and not self.environ["REQUEST_METHOD"] == "HEAD":
+            return True
+
+        return False
+
     def __set_request_method(self):
         """Private method for manually setting the request method.
 
@@ -943,7 +954,7 @@ class Request(Extendable):
 
     def with_errors(self, errors):
         """Easily attach errors message to session request."""
-        return self.with_flash("error", errors)
+        return self.with_flash("errors", errors)
 
     def with_success(self, success):
         """Easily attach success message to session request."""
