@@ -1,4 +1,4 @@
 from .TestCase import TestCase
 from .MockRoute import MockRoute
-from .generate_wsgi import generate_wsgi
+from .generate_wsgi import generate_wsgi, MockWsgiInput
 from .create_container import create_container
